import nodeResolver from '@rollup/plugin-node-resolve';
import commonjs from '@rollup/plugin-commonjs';
import replace from '@rollup/plugin-replace';
import json from '@rollup/plugin-json';
import nodePolyfills from 'rollup-plugin-node-polyfills';
import clear from 'rollup-plugin-clear';
import progress from 'rollup-plugin-progress';
import typescript from '@rollup/plugin-typescript';
import { terser } from 'rollup-plugin-terser';
// import pkg from './package.json';

const isProd = process.env.NODE_ENV === 'production';

const formats = {
  commonjs: {
    format: 'cjs',
    file: 'lib/ywfe-tools.cjs',
    sourcemap: true,
    exports: 'named',
  },
  esm: {
    format: 'esm',
    file: 'lib/ywfe-tools.esm.js',
    sourcemap: true,
    exports: 'named',
  },
  umd: {
    format: 'umd',
    file: 'lib/ywfe-tools.umd.js',
    name: 'YWTOOLS',
    sourcemap: true,
    exports: 'named',
    globals: {
      'react': 'React',
      'react-dom': 'ReactDOM',
    },
  },
};

const config = {
  input: './index.ts',
  inlineDynamicImports: true,
  output: [formats.esm, formats.commonjs],
  external: ['react', 'react-dom'],
  plugins: [
    clear({
      targets: ['lib'],
    }),
    progress({
      clearLine: false,
    }),
    replace({
      NODE_ENV: JSON.stringify(process.env.NODE_ENV || 'development'),
    }),
    nodeResolver(),
    commonjs(),
    typescript(),
    json(),
    nodePolyfills(),
  ],
};

if (isProd) {
  const file = formats.umd.file;

  config.output.push({
    ...formats.umd,
    file,
    plugins: [terser()],
  });
}

export default config;
